/*
 * Copyright 2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

#ifndef _PIN_MUX_H_
#define _PIN_MUX_H_

/*!
 * @addtogroup pin_mux
 * @{
 */

/***********************************************************************************************************************
 * API
 **********************************************************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif

/*!
 * @brief Calls initialization functions.
 *
 */
void BOARD_InitBootPins(void);

#define SOPT5_UART1TXSRC_UART_TX 0x00u /*!<@brief UART 1 transmit data source select: UART1_TX pin */

/*! @name PORTC3 (coord A11), J10[2]/J11[A38]/J11[A64]/UART1_RX
  @{ */
#define BOARD_DEBUG_UART_RX_PORT PORTC /*!<@brief PORT device name: PORTC */
#define BOARD_DEBUG_UART_RX_PIN 3U     /*!<@brief PORTC pin index: 3 */
                                       /* @} */

/*! @name PORTC4 (coord A9), J11[A37]/J15[2]/J11[A69]/UART1_TX
  @{ */
#define BOARD_DEBUG_UART_TX_PORT PORTC /*!<@brief PORT device name: PORTC */
#define BOARD_DEBUG_UART_TX_PIN 4U     /*!<@brief PORTC pin index: 4 */
                                       /* @} */

/*! @name PORTE6 (coord E1), J30[1]/D5/LED1
  @{ */
#define BOARD_LED_GREEN_PORT PORTE /*!<@brief PORT device name: PORTE */
#define BOARD_LED_GREEN_PIN 6U     /*!<@brief PORTE pin index: 6 */
                                   /* @} */

/*! @name PORTE7 (coord F4), J30[3]/D6/LED2
  @{ */
#define BOARD_LED_YELLOW_PORT PORTE /*!<@brief PORT device name: PORTE */
#define BOARD_LED_YELLOW_PIN 7U     /*!<@brief PORTE pin index: 7 */
                                    /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitPins(void);

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_I2C_ConfigurePins(void);

/*! @name PORTC10 (coord C7), J3[3]/J11[A75]/U6[4]/I2C1_SCL
  @{ */
#define BOARD_ACCEL_I2C_SCL_GPIO GPIOC /*!<@brief GPIO device name: GPIOC */
#define BOARD_ACCEL_I2C_SCL_PORT PORTC /*!<@brief PORT device name: PORTC */
#define BOARD_ACCEL_I2C_SCL_PIN 10U    /*!<@brief PORTC pin index: 10 */
                                       /* @} */

/*! @name PORTC11 (coord B7), J3[4]/J11[A60]/J11[B71]/U6[6]/I2C1_SDA
  @{ */
#define BOARD_ACCEL_I2C_SDA_GPIO GPIOC /*!<@brief GPIO device name: GPIOC */
#define BOARD_ACCEL_I2C_SDA_PORT PORTC /*!<@brief PORT device name: PORTC */
#define BOARD_ACCEL_I2C_SDA_PIN 11U    /*!<@brief PORTC pin index: 11 */
                                       /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_Init_I2C_GPIO_pins(void);

#if defined(__cplusplus)
}
#endif

/*!
 * @}
 */
#endif /* _PIN_MUX_H_ */

/***********************************************************************************************************************
 * EOF
 **********************************************************************************************************************/
